@@ -1,5 +1,5 @@
 #' Solutions from the quadratic equation
-#' 
+#'
 #' General function to solve classic quadratic equation:
 #' \deqn{ a x^2 + b x + c = 0 }
 #'
@@ -14,18 +14,21 @@
 #'
 #' @examples
 #' quadratic_eqn(a = 2, b = 4, c = -6)
-quadratic_eqn <- function(a,b,c){
-  delta <- function(a,b,c){
-    b^2-4*a*c
+#'
+quadratic_eqn <- function(a, b, c) {
+  disc <- b^2 - 4 * a * c
+  if (!is.finite(disc) || !is.finite(a) || a == 0) {
+    return(numeric(0))  # Return empty vector on invalid input
   }
-  if(delta(a,b,c) > 0){ 
-    x1 = (-b+sqrt(delta(a,b,c)))/(2*a)
-    x2 = (-b-sqrt(delta(a,b,c)))/(2*a)
-    return(c(x1,x2))
-  }
-  else if(delta(a,b,c) == 0){ 
-    x = -b/(2*a)
+
+  if (disc > 0) {
+    x1 <- (-b + sqrt(disc)) / (2 * a)
+    x2 <- (-b - sqrt(disc)) / (2 * a)
+    return(c(x1, x2))
+  } else if (disc == 0) {
+    x <- -b / (2 * a)
     return(x)
+  } else {
+    return(numeric(0))  # No real roots
   }
-  else {"There are no real roots."} 
 }
